@@ -699,7 +699,8 @@ void quf_table_sum_single(void *px_in, std::string &x_type, int n, int q, int *x
 void quf_refactor_table_sum_single(int n, int *quf_old, int *quf_new, vector<bool> &obs_removed,
                                    vector<double> &x_unik, vector<double> &x_unik_new, vector<double> &x_removed,
                                    vector<int> &x_table, double *py, vector<double> &sum_y, bool do_sum_y,
-                                   bool rm_1, vector<bool> &id_pblm, bool check_pblm, bool *pstop_now){
+                                   bool rm_1, bool rm_single, vector<bool> &id_pblm, bool check_pblm,
+                                   bool *pstop_now, int n_FE){
     // takes in the old quf, the observations removed,
     // then recreates the vectors of:
     // quf, table, sum_y, x_unik_new
@@ -714,10 +715,21 @@ void quf_refactor_table_sum_single(int n, int *quf_old, int *quf_new, vector<boo
     // NOTA: I don't reiterate the observation removal => just one round
     //  (otherwise it could go several rounds => too time consuming, no big value added)
 
-    if((rm_1 || !check_pblm) && !*pstop_now){
+    // if n_FE = 1, no need to recheck the removal since by definition it can't be messed up
+    // by the other dimensions. Everything is done properly directly.
+
+    if((rm_single || rm_1 || !check_pblm) && !*pstop_now && n_FE > 1){
         // If we haven't excluded observations because of 0 only values (ie check_pblm == false)
         // then we here need to update id_pblm, because some IDs could have been taken
         // out due to other FEs being removed
+        // we also need to recheck when singletons are removed
+
+        // The fact that we don't need to recheck when removing only 0s is an oddity
+        // Indeed, when removing only 0s, the IDs of one dimension aren't messed up
+        // by the removal of observations from other dimensions because if they
+        // were to be removed because of this, this would mean that all values
+        // of this ID are 0, so they'd be removed anyway from their own dimension
+        // in the first place.
 
         // the new ID problem => what are the IDs that still exists?
         vector<bool> id_still_exists(D, false);
@@ -726,15 +738,19 @@ void quf_refactor_table_sum_single(int n, int *quf_old, int *quf_new, vector<boo
 
         // we recompute the table and sum_y
         std::fill(x_table.begin(), x_table.end(), 0);
-        std::fill(sum_y.begin(), sum_y.end(), 0);
+        // std::fill(sum_y.begin(), sum_y.end(), 0);
 
-        int id;
+        if(do_sum_y){
+            std::fill(sum_y.begin(), sum_y.end(), 0);
+        }
+
+        int id = 0;
         for(int i=0 ; i<n ; ++i){
             if(!obs_removed[i]){
                 id = quf_old[i] - 1;
                 if(!id_still_exists[id]) id_still_exists[id] = true;
                 ++x_table[id];
-                sum_y[id] += py[i];
+                if(do_sum_y) sum_y[id] += py[i];
             }
         }
 
@@ -744,9 +760,11 @@ void quf_refactor_table_sum_single(int n, int *quf_old, int *quf_new, vector<boo
 
         // Loop finding out the problems
         vector<bool> id_pblm_check(D, false);
-        for(int d=0 ; d<D ; ++d){
-            if(sum_y[d] == 0 || sum_y[d] == x_table[d]){
-                id_pblm_check[d] = true;
+        if(rm_1){
+            for(int d=0 ; d<D ; ++d){
+                if(sum_y[d] == 0 || sum_y[d] == x_table[d]){
+                    id_pblm_check[d] = true;
+                }
             }
         }
 
@@ -760,7 +778,7 @@ void quf_refactor_table_sum_single(int n, int *quf_old, int *quf_new, vector<boo
 
         // is there a problem?
         bool any_pblm = false;
-        // we check only if needed (if !rm_1 && length(id_pblm) == 0 => means no problem)
+        // we check only if needed (if !rm_single && !rm_1 && length(id_pblm) == 0 => means no problem)
         if(id_pblm.size() > 0){
             for(int d=0 ; d<D ; ++d){
                 if(id_pblm[d]){
@@ -793,6 +811,10 @@ void quf_refactor_table_sum_single(int n, int *quf_old, int *quf_new, vector<boo
 
         int D_new = D - nb_pblm;
 
+        // Rcout << "D new: " << D_new << "\n";
+        // Rcout << "any_pblm: " << any_pblm << "\n";
+        // Rcout << "id_pblm size: " << id_pblm.size() << "\n";
+
         x_table.resize(D_new);
         std::fill(x_table.begin(), x_table.end(), 0);
         if(do_sum_y){
@@ -1067,8 +1089,9 @@ List cpppar_quf_table_sum(SEXP x, SEXP y, bool do_sum_y, bool rm_0, bool rm_1,
         for(int q=0 ; q<Q ; ++q){
             quf_refactor_table_sum_single(n, p_x_quf_all[q], p_x_new_quf_all[q], obs_removed,
                                           x_unik_all[q], x_new_unik_all[q], x_removed_all[q],
-                                        x_table_all[q], py, sum_y_all[q], do_sum_y,
-                                        rm_1, id_pblm_all[q], check_pblm[q], pstop_now);
+                                          x_table_all[q], py, sum_y_all[q], do_sum_y,
+                                          rm_1, rm_single, id_pblm_all[q], check_pblm[q],
+                                          pstop_now, Q);
         }
 
         if(*pstop_now){
